import { AdaptiveTicker } from "./adaptive_ticker";
export class BasicTicker extends AdaptiveTicker {
    constructor(attrs) {
        super(attrs);
    }
}
BasicTicker.__name__ = "BasicTicker";
//# sourceMappingURL=basic_ticker.js.map