export const root: string
export const toolbar_hidden: string
export const toolbar: string
export const logo: string
export const above: string
export const below: string
export const left: string
export const right: string
export const toolbar_button: string
export const tool_overflow: string
export const active: string
export const divider: string
export const horizontal: string
export const vertical: string
export default ""
